@@ -206,7 +206,7 @@ def check_url(url, decode_components=False):
     "refresh_interval",
     default=RQ_MONITOR_REFRESH_INTERVAL,
     type=int,
-    help="Refresh interval in ms",
+    help="Refresh interval in ms. Default: 2000",
 )
 @click.option(
     "--extra-path",
@@ -270,4 +270,4 @@ def main():
     run(auto_envvar_prefix="RQ_MONITOR")
 
 if __name__ == '__main__':
-    main()
\ No newline at end of file
+    main()
